@@ -5,12 +5,10 @@ import re
 import uuid
 from collections import defaultdict
 from docx2python import docx2python
-from docassemble.base.error import DAError
-from docassemble.base.util import log, space_to_underscore, bold, DAObject, DAList, DAFile, DAFileList, path_and_mimetype, user_info
+from docassemble.base.util import log, space_to_underscore, bold, DAObject, DAList, DAFile, DAFileList, path_and_mimetype, user_info, DAEmpty
 import docassemble.base.functions
 import docassemble.base.parse
 import docassemble.base.pdftk
-from docassemble.base.core import DAEmpty
 import datetime
 import zipfile
 import json
@@ -917,6 +915,9 @@ def get_docx_variables( text:str )->set:
   # Variables in very simple `if` statements (allow paragraph and whitespace flags)
   for possible_variable in re.findall(r'{%[^ \t]* +if ([^\} ]+) +[^ \t]*%}', text):
     minimally_filtered.add( possible_variable )
+  # Capture variables in `if` statements that contain a comparison
+  for possible_variable in re.findall(r'{%[^ \t]* +if ([^\} ]+) ==|is|>|<|!=|<=|>= .* +[^ \t]*%}', text):  
+    minimally_filtered.add( possible_variable )
 
   fields = set()
 
